.. -*- coding: utf-8 -*-
.. _algebraic_combinatorics:

===============================
Algebraic Combinatorics in Sage
===============================

.. MODULEAUTHOR:: Anne Schilling (UC Davis)

These notes provide some Sage examples for Stanley's book:

.. [Stanley2013] Richard Stanley.
   *Algebraic Combinatorics: walks, trees, tableaux and more*,
   Springer, first edition, 2013.

A free pdf version of the book without exercises can be found on
`Stanley's homepage <http://www-math.mit.edu/~rstan/algcomb/index.html>`_.

Preparation of this document was supported in part by NSF grants DMS--1001256 and OCI–1147247.

I would like to thank Federico Castillo (who wrote a first version of the `n`-cube section)
and Nicolas M. Thiery (who wrote a slightly different French version of the Tsetlin library
section) for their help.

.. toctree::
   :maxdepth: 1

   algebraic_combinatorics/walks
   algebraic_combinatorics/n_cube
   algebraic_combinatorics/tsetlin_library
   algebraic_combinatorics/rsk.rst

